Chat.tree — alfred3_interact

Skip to main content
`Ctrl`+`K`

# Chat.tree

property Chat.tree: str

  String, giving the exact position in the experiment.

  The tree is composed of the names of all sections and the element’s page dots. Example for an element that belongs to a page “hello_world” that was added directly to the experiment:

      _root._content.hello_world

  `_root` and `_content` are basic sections that alfred always includes in an experiment.

  Type

    str